# Changelog

All notable changes to this project will be documented in this file.

## [0.0.1] - 2024-06-23

### 🐛 Bug Fixes

- Serialization method fixed
- Trying to fix deserialization
- Deserialised method fixed.fixed all mypy errors
- Tests fixed. 2 more to go. error: Romve the forks is not working properly maybe
- Fixed 9 tests & all of them are passing
- All workflow erros fixed
- Fixed typo in build workflow
- Fixed workflow to install bee-factory properly
- Updated worflows to run only on linux

### 📚 Documentation

- Fixed authors.md
- Fixing authors.md
- Fixing authors.md
- Fixed other doc files
- Syntax fixed. chore: added comments in serialise method of the MantarayFork class
- Changelogs updated
- Readme updated. fix: fixed issues with documentations
- Readme updated. Examples.md page added. Index of docs webpage is updated
- Docs updated

### 🧪 Testing

- Added unit tests and all tests passed
- Helper methods added for testing
- Integeration test setup done & first test added
- Updated workflows to setup bee test node & run tests on windwos, mac & linux
- Updated workflows to skip integration tests on windows
- Don't need to run tests again for release if the build tests are passed
- Updated workflows to run integration tests only on linux
- Fixed workflows to run run bee test node for linux only
- Conftest.py updated
- Trying to fix issues with macOS workflow
- Updated conftest.py file fixtures & removed autouse attribute

### ⚙️ Miscellaneous Tasks

- Updated changelog
- Updated changelog
- Updated core version manager to regex_commit from hatch-vcs

### Del

- Remove _version.py from version control

### Error

- Serialise method seems to be faulty
- Issue with the encrypt_decrypt function. have to fix deserialise as well
- Some reason fork is None for path=b'/'
- Still issue with the serialised object retruend. it has a extra white space character which is changing the whole hash
- For some search terminal node forks are None instead of {}

<!-- generated by git-cliff -->
